# Python package for easy conversion between units systems.

### Relation only between SI and Atomic Units yet...
**Use**: 
> import from unitscvt.**module** *conversion_const* 
> value_in_SI = value_in_atomicunits* *conversion_const*

Contain modules:
- `siconst.py`: five defining constants of the SI units (plus Dalton and electronvolt)
- `aunits.py`: conversion constants between atomic units and SI
